@@ -1,10 +1,14 @@
 
 
 from datetime import datetime
-from jbg_util.file_util import FileManager
-from jbg_util.data_converter import DataConverter
-from jbg_util.models.binance_models import BinanceApiKeys
+from jbg_util import file_util
+from jbg_util import data_converter
+from jbg_util import binance_models
 import os
+
+BinanceApiKeys = binance_models.BinanceApiKeys
+DataConverter = data_converter.DataConverter
+FileManager = file_util.FileManager
 def binance_timestamp_to_dte(ts : int):
     return datetime.utcfromtimestamp(ts/1000)
 
