@@ -10,7 +10,7 @@ class Subscriber:
 
 class PubSubMediator:
     def __init__(self):
-        self.subscribers_by_channel : dict[str,list[Subscriber]] = {}
+        self.subscribers_by_channel = {}
 
     async def publish(self, data, channel : str):
         if channel not in self.subscribers_by_channel:
